@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
 
 
-class WeatherService(ABC):
+class WxService(ABC):
     def __init__(self, credential):
         self.credential = credential
 
